package com.tolfy.demo12345.config;

import com.google.common.base.Predicates;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

/**
 * @Author Tuerlechat,
 * @Date 2022/12/5
 */
@Configuration  //设置配置类
@EnableSwagger2    //开启swagger2
public class SwaggerConfig {

    @Bean
    public Docket webApiConfig(){

        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("主页api接口")    //起一个分组名
                .apiInfo(webApiInfo())  //添加下面对应的方法
                .select()
                //过滤掉admin路径下的所有页面
                .paths(Predicates.not(PathSelectors.regex("/admin/.*")))
                //过滤掉所有error或error.*页面（默认有一个error页面）
                .paths(Predicates.not(PathSelectors.regex("/error.*")))
                .build();

    }

    @Bean
    public Docket adminApiConfig(){

        return new Docket(DocumentationType.SWAGGER_2)
                .groupName("管理员api接口")  //起一个分组名
                .apiInfo(adminApiInfo())    //添加下面对应的方法
                .select()
                //只显示admin路径下的页面
                .paths(Predicates.and(PathSelectors.regex("/admin/.*")))
                .build();

    }

    /**
     * 对应上面的实现方法
     * @return
     */
    private ApiInfo webApiInfo(){

        return new ApiInfoBuilder()
                .title("swagger2—测试API文档")  //标题
                .description("本文档描述了对swagger2进行使用测试")   //描述
                .version("1.3") //版本
                //网站访问跳转链接和发送邮箱
                .contact(new Contact("我的主页",
                        "http://note.youdao.com/noteshare?id=099f303ebbad1aa2c4e5b82fb5a28e12&sub=F20546FED38C4DE28BA0827035F631DB",
                        "111111@qq.com"))
                .build();
    }

    /**
     * 对应上面的实现方法
     * @return
     */
    private ApiInfo adminApiInfo(){

        return new ApiInfoBuilder()
                .title("swagger2-测试使用API文档2")
                .description("本文档描述了对swagger2进行使用测试的一些信息")
                .version("1.0")
                .contact(new Contact("林志伟随手笔记", "http://note.youdao.com/noteshare?id=099f303ebbad1aa2c4e5b82fb5a28e12&sub=F20546FED38C4DE28BA0827035F631DB", "111111@qq.com"))
                .build();
    }

}
